Description Usage Arguments Value
For each voxel in a 3D logical array, count the number of immediate neighbors
with value TRUE.
1 | neighbor_counts(arr, pad = FALSE)
|
arr |
The 3D logical array. |
pad |
Pad value for edge. |
An array with the same dimensions as arr. Each voxel value
will be the number of its immediate neighbors (0 to 6) which are TRUE.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.