| FD | R Documentation |
Calculate Framewise Displacement (FD)
FD(
X,
trans_units = c("mm", "cm", "in"),
rot_units = c("deg", "rad", "mm", "cm", "in"),
brain_radius = NULL,
detrend = FALSE,
TR_for_resp_filt = NULL,
lag = 1,
cutoff = 0.4
)
X |
An Alternatively, this can be the file path to an |
trans_units |
|
rot_units |
|
brain_radius |
If If |
detrend |
Detrend each RP with the DCT before computing FD?
Default: |
TR_for_resp_filt |
Filter out the respiratory frequency? If so, provide
the temporal resolution (TR) in seconds, which is needed to calculate the
filter. Default: Power et al. (2019) and Fair et al. (2020) have shown that in multiband
data, the RPs may contain head movements which accompany normal respiration,
as well as artifactual variance in the phase encode direction at the
respiratory frequency. They propose applying a notch filter to the RPs to
remove variance within the frequency range of respiration; in particular,
Fair et al. (2020) used a second-order IIR filter between 0.31 and 0.43 Hz.
Here, we use a 0.31-0.43 Hz Chebyshev Type II stop-gap filter, with 20 dB
stopband ripple, from the The filter will be applied after any detrending. If filtering, consider
adjusting |
lag |
The difference of indices between which to calculate change in
position. Default: |
cutoff |
FD values higher than this will be flagged. Default: |
The FD formula is taken from Power et al. (2012):
FD_i = | \Delta x_i | + | \Delta y_i | + | \Delta z_i | + | \Delta \alpha_i | + | \Delta \beta_i | + | \Delta \gamma_i |
where i is the timepoint; x, y and z are the
translational realignment parameters (RPs);
\alpha, \beta and \gamma are the rotational RPs;
and \Delta x_i = x_{i-1} - x_i (and similarly for the other RPs).
A list with components
A length N vector of FD values in trans_units.
"FD"
cutoff
A length-N logical vector, where TRUE indicates suspected outlier presence.
Power, J. D., Barnes, K. A., Snyder, A. Z., Schlaggar, B. L., & Petersen, S. E. (2012). Spurious but systematic correlations in functional connectivity MRI networks arise from subject motion. Neuroimage, 59(3), 2142-2154.
Power, J. D., Lynch, C. J., Silver, B. M., Dubin, M. J., Martin, A., & Jones, R. M. (2019). Distinctions among real and apparent respiratory motions in human fMRI data. NeuroImage, 201, 116041.
Fair, D. A., Miranda-Dominguez, O., Snyder, A. Z., Perrone, A., Earl, E. A., Van, A. N., ... & Dosenbach, N. U. (2020). Correction of respiratory artifacts in MRI head motion estimates. Neuroimage, 208, 116400.
Pham, D. D., McDonald, D. J., Ding, L., Nebel, M. B., & Mejia, A. F. (2023). Less is more: balancing noise reduction and data retention in fMRI with data-driven scrubbing. NeuroImage, 270, 119972.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.